@@ -28,6 +28,7 @@
 #include "VirtualTerminal.h"
 #include "XAuth.h"
 
+#include <linux/kd.h>
 #include <functional>
 #include <iostream>
 #include <sys/types.h>
@@ -217,7 +218,7 @@ namespace DDM {
             // when this is true we'll take control of the tty
             bool takeControl = false;
 
-            if (vtFd > 0 && !m_helperApp->isSingleMode()) {
+            if (vtFd > 0) {
                 dup2(vtFd, STDIN_FILENO);
                 ::close(vtFd);
                 takeControl = true;
@@ -232,6 +233,7 @@ namespace DDM {
                 qCritical("Failed to set pid %lld as leader of the new session and process group: %s",
                           QCoreApplication::applicationPid(), strerror(errno));
                 _exit(Auth::HELPER_OTHER_ERROR);
+
             }
 
             // take control of the tty
@@ -241,18 +243,13 @@ namespace DDM {
                     qCritical().nospace() << "Failed to take control of " << ttyString << " (" << QFileInfo(ttyString).owner() << "): " << error;
                     _exit(Auth::HELPER_TTY_ERROR);
                 }
+                if (ioctl(STDIN_FILENO, KDSKBMODE, K_OFF) == -1) {
+                    qCritical().nospace() << "Failed to set keyboard mode to K_OFF";
+                    _exit(Auth::HELPER_TTY_ERROR);
+                }
             }
 
-            if (m_helperApp->isSingleMode() && m_helperApp->isGreeter()) {
-                // FIXME: if jumpToVt vt_auto is false, when switching tty, greeter sesion will died.
-                VirtualTerminal::jumpToVt(vtNumber, true);
-
-                // disable physical tty standard output in greeter work tty.
-                struct termios tios;
-                tcgetattr(STDOUT_FILENO, &tios);
-                tios.c_oflag &= ~OPOST;
-                tcsetattr(STDOUT_FILENO, TCSANOW, &tios);
-            }
+            VirtualTerminal::jumpToVt(vtNumber, !waylandUserSession);
         }
 
 #ifdef Q_OS_LINUX
